==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/content/logistics/filter/AttributeFilterItem.java <==
package com.zurrtum.create.content.logistics.filter;

import com.zurrtum.create.AllDataComponents;
import com.zurrtum.create.content.logistics.filter.FilterItemStack.AttributeFilterItemStack;
import com.zurrtum.create.content.logistics.item.filter.attribute.ItemAttribute;
import com.zurrtum.create.content.logistics.item.filter.attribute.attributes.InTagAttribute;
import com.zurrtum.create.foundation.gui.menu.MenuBase;
import com.zurrtum.create.infrastructure.component.AttributeFilterWhitelistMode;
import com.zurrtum.create.infrastructure.component.ItemAttributeEntry;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import net.minecraft.class_124;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_6880;
import net.minecraft.class_7923;
import net.minecraft.class_9129;
import net.minecraft.class_9331;

public class AttributeFilterItem extends FilterItem {
    protected AttributeFilterItem(class_1793 properties) {
        super(properties);
    }

    @Override
    public List<class_2561> makeSummary(class_1799 filter) {
        List<class_2561> list = new ArrayList<>();

        AttributeFilterWhitelistMode whitelistMode = filter.method_58694(AllDataComponents.ATTRIBUTE_FILTER_WHITELIST_MODE);
        list.add((whitelistMode == AttributeFilterWhitelistMode.WHITELIST_CONJ ? class_2561.method_43471(
            "create.gui.attribute_filter.allow_list_conjunctive") : whitelistMode == AttributeFilterWhitelistMode.WHITELIST_DISJ ? class_2561.method_43471(
            "create.gui.attribute_filter.allow_list_disjunctive") : class_2561.method_43471("create.gui.attribute_filter.deny_list")).method_27692(class_124.field_1065));

        int count = 0;
        List<ItemAttributeEntry> attributes = filter.method_58695(AllDataComponents.ATTRIBUTE_FILTER_MATCHED_ATTRIBUTES, List.of());
        for (ItemAttributeEntry attributeEntry : attributes) {
            ItemAttribute attribute = attributeEntry.attribute();
            if (attribute == null)
                continue;
            boolean inverted = attributeEntry.inverted();
            if (count > 3) {
                list.add(class_2561.method_43470("- ...").method_27692(class_124.field_1063));
                break;
            }
            list.add(class_2561.method_43470("- ").method_10852(attribute.format(inverted)));
            count++;
        }

        if (count == 0)
            return Collections.emptyList();

        return list;
    }

    @Override
    public @Nullable MenuBase<?> createMenu(int id, class_1661 inv, class_1657 player, class_9129 extraData) {
        class_1799 heldItem = player.method_6047();
        class_1799.field_48349.encode(extraData, heldItem);
        return new AttributeFilterMenu(id, inv, heldItem);
    }

    @Override
    public class_9331<?> getComponentType() {
        return AllDataComponents.ATTRIBUTE_FILTER_MATCHED_ATTRIBUTES;
    }

    @Override
    public FilterItemStack makeStackWrapper(class_1799 filter) {
        return new AttributeFilterItemStack(filter);
    }

    @Override
    public class_1799[] getFilterItems(class_1799 stack) {
        AttributeFilterWhitelistMode whitelistMode = stack.method_58694(AllDataComponents.ATTRIBUTE_FILTER_WHITELIST_MODE);
        List<ItemAttributeEntry> attributes = stack.method_58695(AllDataComponents.ATTRIBUTE_FILTER_MATCHED_ATTRIBUTES, List.of());

        if (whitelistMode == AttributeFilterWhitelistMode.WHITELIST_DISJ && attributes.size() == 1) {
            ItemAttribute attribute = attributes.getFirst().attribute();
            if (attribute instanceof InTagAttribute(TagKey<Item> tag)) {
                List<class_1799> stacks = new ArrayList<>();
                for (class_6880<class_1792> holder : class_7923.field_41178.method_40286(tag)) {
                    stacks.add(new class_1799(holder.comp_349()));
                }
                return stacks.toArray(class_1799[]::new);
            }
        }
        return new class_1799[0];
    }
}

==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/content/logistics/filter/AttributeFilterItem.java <==
package com.zurrtum.create.content.logistics.filter;

import com.zurrtum.create.AllDataComponents;
import com.zurrtum.create.content.logistics.filter.FilterItemStack.AttributeFilterItemStack;
import com.zurrtum.create.content.logistics.item.filter.attribute.ItemAttribute;
import com.zurrtum.create.content.logistics.item.filter.attribute.attributes.InTagAttribute;
import com.zurrtum.create.foundation.gui.menu.MenuBase;
import com.zurrtum.create.infrastructure.component.AttributeFilterWhitelistMode;
import com.zurrtum.create.infrastructure.component.ItemAttributeEntry;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import net.minecraft.class_124;
import net.minecraft.class_1657;
import net.minecraft.class_1661;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2561;
import net.minecraft.class_6862;
import net.minecraft.class_6880;
import net.minecraft.class_7923;
import net.minecraft.class_9129;
import net.minecraft.class_9331;

public class AttributeFilterItem extends FilterItem {
    protected AttributeFilterItem(class_1793 properties) {
        super(properties);
    }

    @Override
    public List<class_2561> makeSummary(class_1799 filter) {
        List<class_2561> list = new ArrayList<>();

        AttributeFilterWhitelistMode whitelistMode = filter.method_58694(AllDataComponents.ATTRIBUTE_FILTER_WHITELIST_MODE);
        list.add((whitelistMode == AttributeFilterWhitelistMode.WHITELIST_CONJ ? class_2561.method_43471(
            "create.gui.attribute_filter.allow_list_conjunctive") : whitelistMode == AttributeFilterWhitelistMode.WHITELIST_DISJ ? class_2561.method_43471(
            "create.gui.attribute_filter.allow_list_disjunctive") : class_2561.method_43471("create.gui.attribute_filter.deny_list")).method_27692(class_124.field_1065));

        int count = 0;
        List<ItemAttributeEntry> attributes = filter.method_58695(AllDataComponents.ATTRIBUTE_FILTER_MATCHED_ATTRIBUTES, List.of());
        for (ItemAttributeEntry attributeEntry : attributes) {
            ItemAttribute attribute = attributeEntry.attribute();
            if (attribute == null)
                continue;
            boolean inverted = attributeEntry.inverted();
            if (count > 3) {
                list.add(class_2561.method_43470("- ...").method_27692(class_124.field_1063));
                break;
            }
            list.add(class_2561.method_43470("- ").method_10852(attribute.format(inverted)));
            count++;
        }

        if (count == 0)
            return Collections.emptyList();

        return list;
    }

    @Override
    public @Nullable MenuBase<?> createMenu(int id, class_1661 inv, class_1657 player, class_9129 extraData) {
        class_1799 heldItem = player.method_6047();
        class_1799.field_48349.encode(extraData, heldItem);
        return new AttributeFilterMenu(id, inv, heldItem);
    }

    @Override
    public class_9331<?> getComponentType() {
        return AllDataComponents.ATTRIBUTE_FILTER_MATCHED_ATTRIBUTES;
    }

    @Override
    public FilterItemStack makeStackWrapper(class_1799 filter) {
        return new AttributeFilterItemStack(filter);
    }

    @Override
    public class_1799[] getFilterItems(class_1799 stack) {
        AttributeFilterWhitelistMode whitelistMode = stack.method_58694(AllDataComponents.ATTRIBUTE_FILTER_WHITELIST_MODE);
        List<ItemAttributeEntry> attributes = stack.method_58695(AllDataComponents.ATTRIBUTE_FILTER_MATCHED_ATTRIBUTES, List.of());

        if (whitelistMode == AttributeFilterWhitelistMode.WHITELIST_DISJ && attributes.size() == 1) {
            ItemAttribute attribute = attributes.getFirst().attribute();
            if (attribute instanceof InTagAttribute(class_6862<class_1792> tag)) {
                List<class_1799> stacks = new ArrayList<>();
                for (class_6880<class_1792> holder : class_7923.field_41178.method_40286(tag)) {
                    stacks.add(new class_1799(holder.comp_349()));
                }
                return stacks.toArray(class_1799[]::new);
            }
        }
        return new class_1799[0];
    }
}
